@@ -1,3 +1,19 @@
+/**
+ * Copyright 2017 Red Hat Inc.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
 import { defineMessages, injectIntl } from 'react-intl';
 import ImmutablePropTypes from 'react-immutable-proptypes';
 import PropTypes from 'prop-types';
@@ -37,7 +53,7 @@ class DeploymentSuccess extends React.Component {
           <p>{this.props.stack.stack_status_reason}</p>
         </InlineNotification>
         <OvercloudInfo
-          stackResourcesLoaded={this.props.stackResourcesLoaded}
+          overcloudInfo={this.props.overcloudInfo}
           stack={this.props.stack}
           stackResources={this.props.stackResources}
         />
@@ -60,9 +76,9 @@ DeploymentSuccess.propTypes = {
   fetchStackResource: PropTypes.func.isRequired,
   intl: PropTypes.object,
   isRequestingStackDelete: PropTypes.bool,
+  overcloudInfo: ImmutablePropTypes.map.isRequired,
   stack: ImmutablePropTypes.record.isRequired,
-  stackResources: ImmutablePropTypes.map.isRequired,
-  stackResourcesLoaded: PropTypes.bool.isRequired
+  stackResources: ImmutablePropTypes.map.isRequired
 };
 
 export default injectIntl(DeploymentSuccess);
